import React from 'react';

import { CookiesProvider, useCookies } from 'react-cookie';
import ReactGA from 'react-ga4';
import { HelmetProvider } from 'react-helmet-async';
import { BrowserRouter, useLocation } from 'react-router-dom';
import './App.css';
import AppRoot from './common/AppRoot';
import Config, { MultiLang } from './config';

const mlang = ['en', 'ja'] as const;
const isMultiLang = (name: string): name is MultiLang => {
  return mlang.some((value) => value === name);
};

const AppMain: React.FC = () => {
  const [cookies, setCookie] = useCookies();
  const typedCookies = cookies as Record<string, string>;
  const [lang, setLang] = React.useState<MultiLang>(
    isMultiLang(typedCookies?.ml_lang ?? '') ? (cookies.ml_lang as MultiLang) : 'en',
  );
  const location = useLocation();

  React.useEffect(() => {
    const params = new URLSearchParams(location.search);
    const ml_lang = params.get('ml_lang');
    if (ml_lang != null && ['en', 'ja'].includes(ml_lang)) {
      if (cookies.ml_lang !== ml_lang) {
        setCookie('ml_lang', ml_lang);
      }
      if (lang !== ml_lang) {
        setLang(ml_lang as MultiLang);
      }
    }
    window.scrollTo(0, 0);
  }, [location, cookies, setCookie, lang, setLang]);

  return <AppRoot lang={lang} />;
};

const App: React.FC = () => {
  if (Config.GOOGLE_ANALYTICS_TRACKING_ID.startsWith('G-')) {
    ReactGA.initialize(Config.GOOGLE_ANALYTICS_TRACKING_ID);
  }

  return (
    <BrowserRouter>
      <CookiesProvider>
        <HelmetProvider>
          <AppMain />
        </HelmetProvider>
      </CookiesProvider>
    </BrowserRouter>
  );
};

export default App;
